use <support_montre.scad>;

r_ecrou_m3=3.3;
r_trou_m3=1.5;

l1_fixation=50;
l2_fixation=18;
ep_fixation=15;

l1_base=115;
r_base=10;

l1_tel=116.5;
l2_tel=63.5;
ep_tel=16;
ep_paroi=3;


module charniere(largeur,hauteur){
	difference(){
		union(){
			cube([largeur,hauteur/2,hauteur]);
			translate([0,hauteur/2,hauteur/2]){rotate([0,90,0])cylinder(h = largeur, r = hauteur/2, $fn=100);}
		}

		//trou de perçage au centre
		translate([-5,hauteur/2+0.25,hauteur/2]){rotate([0,90,0])cylinder(h = largeur+10, r = r_trou_m3, $fn=50);}

		//trou pour écrou M3 nylstop de serrage à gauche
		translate([-5,hauteur/2+0.25,hauteur/2]){rotate([0,90,0])cylinder(h = 8, r = r_ecrou_m3, $fn=6);}
	}
}



module fixation_planchette(){
	difference(){
		cube([l1_fixation,l2_fixation,ep_fixation]);

		translate([-5,-5,ep_fixation-1.5]){cube([l1_fixation+10,l2_fixation+3,ep_fixation]);}

		//trous de vissage
		translate([5,l2_fixation/2,-5]){cylinder(h = 25, r = r_trou_m3, $fn=50);}
		translate([5,l2_fixation/2,-5]){cylinder(h = 12, r = r_ecrou_m3, $fn=6);}

		translate([l1_fixation-5,l2_fixation/2,-5]){cylinder(h = 25, r = r_trou_m3, $fn=50);}
		translate([l1_fixation-5,l2_fixation/2,-5]){cylinder(h = 12, r = r_ecrou_m3, $fn=6);}
	}

	//éléments de charnière sur la fixation planchette
	translate([0,l2_fixation,0]){charniere(10,ep_fixation);}
	translate([20,l2_fixation,0]){charniere(10,ep_fixation);}
	translate([40,l2_fixation,0]){charniere(10,ep_fixation);}
}

module plaque_fixation_planchette(){ //pour pincer les feuilles
	difference(){
		cube([l1_fixation,l2_fixation-1.5,3]);

		//trous de vissage
		translate([5,l2_fixation/2,-5]){cylinder(h = 25, r = r_trou_m3, $fn=50);}
		translate([l1_fixation-5,l2_fixation/2,-5]){cylinder(h = 25, r = r_trou_m3, $fn=50);}
	}

}

module plaque_base(){ //plaque d'articulation de base sur la fixation_planchette
	difference(){
		union(){
			cube([l1_base,13,ep_fixation]);

			//base d'articulation sur l'axe Z
			translate([l1_base,r_base,ep_fixation/2]){cylinder(h = ep_fixation/2, r = r_base, $fn=100);}
		}

		//diminution de la partie gauche du cube
		translate([-5,-5,-5]){cube([27.75,10+10,ep_fixation+10]);}
		hull(){
		//extrusion pour base d'articulation en Z
		translate([l1_base,r_base,-5]){cylinder(h = ep_fixation/2+5, r = r_base+0.5, $fn=100);}
		translate([l1_base+-2,r_base+8,-5]){cylinder(h = ep_fixation/2+5, r = r_base+0.5, $fn=100);}
		}

		//trou central pour vissage
		translate([l1_base,r_base,-5]){cylinder(h = ep_fixation+10, r = r_trou_m3, $fn=50);}
		
	}
	
	translate([l1_base/2-25.25,0,0]){rotate([0,0,180])charniere(9.5,ep_fixation);}
	translate([l1_base/2-5.25,0,0]){rotate([0,0,180])charniere(9.5,ep_fixation);}
	translate([l1_base/2+9.5+5.25,0,0]){rotate([0,0,180])charniere(9.5,ep_fixation);}
	translate([l1_base/2+9.5+20+5.25,0,0]){rotate([0,0,180])charniere(9.5,ep_fixation);}
}

module telephone(){
	difference(){

		hull(){ //forme extérieure
			cylinder(h = ep_tel+2, r = ep_paroi, $fn=50);
			translate([l1_tel,0,0]){cylinder(h = ep_tel+2, r = ep_paroi, $fn=50);}
			translate([l1_tel,l2_tel,0]){cylinder(h = ep_tel+2, r = ep_paroi, $fn=50);}
			translate([0,l2_tel,0]){cylinder(h = ep_tel+2, r = ep_paroi, $fn=50);}
		}

		//trou traversant, arrière du téléphone
		hull(){ //forme extérieure
			translate([10,10,-5]){cylinder(h = ep_tel+10, r = ep_paroi, $fn=50);}
			translate([l1_tel-10,10,-5]){cylinder(h = ep_tel+10, r = ep_paroi, $fn=50);}
			translate([10,l2_tel-10,-5]){cylinder(h = ep_tel+10, r = ep_paroi, $fn=50);}
			translate([l1_tel-10,l2_tel-10,-5]){cylinder(h = ep_tel+10, r = ep_paroi, $fn=50);}
		}

		//trou sur côté, pour bouton power
		translate([20,l2_tel-5,4]){cube([20,10,ep_fixation+5]);}

		//trou sur côté, pour brancher l'USB
		translate([-5,8,4]){cube([20,15,ep_fixation+5]);}

		//extrusion pour emplacement du téléphone

		hull(){ //forme extérieure
			translate([ep_paroi,ep_paroi,2]){cylinder(h = ep_tel+10, r = ep_paroi, $fn=50);}
			translate([l1_tel-ep_paroi,ep_paroi,2]){cylinder(h = ep_tel+10, r = ep_paroi, $fn=50);}
			translate([ep_paroi,l2_tel-ep_paroi,2]){cylinder(h = ep_tel+10, r = ep_paroi, $fn=50);}
			translate([l1_tel-ep_paroi,l2_tel-ep_paroi,2]){cylinder(h = ep_tel+10, r = ep_paroi, $fn=50);}
		}


	}

	difference(){
	//ajout d'une bosse pour maintenir le téléphone à gauche
	translate([ep_paroi-4,ep_paroi-3,14]){rotate([-90,0,0])cylinder(h = l2_tel, r = 2, $fn=50);}

//trou sur côté, pour brancher l'USB
		translate([-5,8,4]){cube([20,15,ep_fixation+5]);}
	}

	//ajout d'une bosse pour maintenir le téléphone à droite
	translate([l1_tel+1,ep_paroi-3,13]){rotate([-90,0,0])cylinder(h = l2_tel, r = 2, $fn=50);}
	
}

module porte_tel(){ //porte téléphone avec articulation en Z
	difference(){
		union(){
		//base d'articulation en Z
		hull(){
		cylinder(h = ep_fixation/2, r = r_base, $fn=100);
		translate([-2,8,0]){cylinder(h = ep_fixation/2, r = r_base, $fn=100);}

		}

		translate([-l1_tel-7,ep_paroi+4,0]){telephone();}

		

		}

		hull(){
			translate([-10,10,2]){cylinder(h = ep_fixation/2, r = ep_paroi, $fn=50);}
			translate([-15,10,2]){cylinder(h = ep_fixation/2, r = ep_paroi, $fn=50);}
			translate([-10,20,2]){cylinder(h = ep_fixation/2, r = ep_paroi, $fn=50);}

		}

		//extrusion pour rotation
		translate([0,0,ep_fixation/2]){cylinder(h = ep_fixation, r = r_base+0.5, $fn=100);}

		//trou central pour montage
		translate([0,0,-5]){cylinder(h = ep_fixation+10, r = r_trou_m3, $fn=50);}
		translate([0,0,-5]){cylinder(h = 8, r = r_ecrou_m3, $fn=6);}
	}
}

module montre(){
fixation_plaque();
translate([0,20,0]){support_montre();}
}

//translate([-l1_fixation/2,0,0]){fixation_planchette();}
translate([-l1_fixation/2,0,20]){plaque_fixation_planchette();}
//translate([-l1_base/2,l2_fixation+ep_fixation+0.5,0]){rotate([0,0,0])plaque_base();}
//translate([l1_base/2,l2_fixation+ep_fixation+10.5,-0.5]){rotate([0,0,0])porte_tel();}

//translate([-115,0,0]){montre();}


