// Snowflake, a hexagon chain mail, V2: chain mail example
//
// Copyright (C) 2012  Lochner, Jrgen
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

////////////////////////////////////////////////////////////////////////
// Set your parameters:

gap=0.3;				// vertical space between 2 hexagons	
size=10;				// radius of hexagon
layers=3;				// height of corners
rows=3;				// horizonatal thickness of hexagon

shift=2.5;				// thickness of "connecting" corners
long=1;  				// 1 = more stable  oder  4 = less material
edges=6; 				// dont change = 6

//
/////////////////////////////////////////////////////////////////////////

/* tiny setting: dont change this:
gap=0.25;				// vertical space between 2 hexagons	
size=4;					// radius of hexagon
layers=1.5;				// height of corners
rows=1;				// horizonatal thickness of hexagon

shift=1.0;				// thickness of "connecting" corners
long=1;  				// 1 = more stable  oder  4 = less material
edges=6; 				// dont change = 6
*/




bridge=(size-rows)*sqrt(3)/2-shift*sin(30)+0.01;  // cutting position +0.01 to be manifold

module zup ()  			// Single Hexagon
{
	difference(){
		cylinder(h=layers,r=size,center=true,$fn=edges);
		cylinder(h=layers+1,r=size-rows,center=true,$fn=edges);

		for (count = [0:1:edges/2-1]) 
		{
			rotate([0,0,360/edges*2*count]) translate([0,shift,-layers/2+gap])
  			  rotate([0,0,30]) translate([bridge/2,size/2,0]) cube([bridge,size*long+shift,layers],center=true);
 			
			rotate([0,0,360/edges*(2*count+1)]) translate([0,shift,+layers/2-gap]) 
			  rotate([0,0,-30]) translate([-bridge/2,size/2,0]) cube([bridge,size*long+shift,layers],center=true);
		}
	}
}



module kreis(){						// 6 elements, circle
for (i=[1:1:6]) { rotate([0,0,i*60]) translate([0,size*1.3,0]) rotate([0,0,60*(i*2)+30])zup(); }
}

module plane(){						// snowflake mesh
kreis();
for(ii=[0:1:5]) { rotate([0,0,30+60*ii])translate([size*3.9,0,0])rotate([0,0,30])kreis();}
}

module tribble(){					// extension for plane()
for(ii=[0:1:2]) { rotate([0,0,30+60*ii])translate([size*3.9,0,0])rotate([0,0,30])kreis(); }
}

module chain(posi=1, anz=5){		// chain : opening position, number of elements
rotate([0,0,60*posi])union(){for (i=[1:1:anz]) { rotate([0,0,i*60]) translate([0,size*1.3,0]) rotate([0,0,60*(i*2)+30])zup(); }}
}

module cplane(){					// opened chain , testing
for(ii=[0:1:3]) { rotate([0,0,30+60*ii])translate([size*3.9,0,0])rotate([0,0,30])chain();}
 rotate([0,0,30+60*4])translate([size*3.9,0,0])rotate([0,0,30])chain(anz=3);
}

module chain01(){					// snowflake chain
for(ii=[0:1:5]) { rotate([0,0,30+60*ii])translate([size*3.9,0,0])rotate([0,0,30])chain();}
}

module cmail(xel=1,yel=1){    		// chainmail with nElements=xel*2 * yel*4 
	for (yi=[0:1:yel-1]){ for (xi=[0:1:xel-1]){ translate([size*2.25*xi,size*3.9*yi,0])chain(anz=4,posi=2);}};
}

/////////////////////////////////////
// Uncommt to view examples:
/////////////////////////////////////

// zup();																			// 1 element

// kreis();																			// 6 elements

// plane();  																			// snowflake mesh

// plane();translate([0,size*3.9,0]) tribble();translate([0,size*3.9*2,0]) tribble();			// extrended snowflake mesh

// chain01();																		// snowflake chain


 cmail (6,3);																			// chainmail with x*2 and y*4 elements

